@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2019-06-26'; # DATE
-our $VERSION = '1.822'; # VERSION
+our $DATE = '2019-07-04'; # DATE
+our $VERSION = '1.823'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -242,6 +242,10 @@ sub hook_before_action {
             (grep { $_->{validate_args} }
              @{ $meta->{'x.perinci.sub.wrapper.logs'} });
 
+        # function can validate its args, so we don't have to do validation for
+        # it
+        last if $meta->{features} && $meta->{features}{validate_vars};
+
         require Data::Sah;
 
         # to be cheap, we simply use "$ref" as key as cache key. to be proper,
@@ -571,7 +575,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.822 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2019-06-26.
+This document describes version 1.823 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2019-07-04.
 
 =head1 SYNOPSIS
 
